Learn R Programming

ergm.sign (version 0.1.2)

InitErgmTerm.delnodematch: Delayed node matching on attribute (lag-1)

Description

Create a nodematch term where node attributes come from the previous network's node attribute `attr`. The previous network used is the one indexed by the current `GroupID` (equivalent to `lag=1` previously). This constructs a temporary node attribute `delnodecov_<attr>` on the current network (copied from the previous net) and calls `nodematch` on that attribute.

Usage

# binary: delnodematch(attr)

Arguments

attr

character attribute name to copy from the previous network into the current.