Learn R Programming

ergm.sign (version 0.1.2)

TNTFixL-ergmProposal: Default MH algorithm respecting the layer constraint

Description

Stratifies the population of dyads edge status: those having ties and those having no ties (hence T/NT). This is useful for improving performance in sparse networks, because it gives at least 50% chance of proposing a toggle of an existing edge.

Arguments

Details

ergm:::.formatProposalsHtml(ergm:::.buildProposalsList(proposal="TNTFixL"))