This term adds one network statistic to the model for each element in `d` where the \(i\) th such statistic equals the number of dyads in the network with exactly `d[i]` shared enemies. For a directed network, multiple shared enemies definitions are possible.
# binary: dse(d, type="OTP", in_order=FALSE)While there is only one shared partner configuration in the undirected case, nine distinct configurations are possible for directed graphs, selected using the `type` argument. Currently, terms may be defined with respect to five of these configurations; they are defined here as follows (using terminology from Butts (2008) and the `relevent` package): - Outgoing Two-path (`"OTP"`): vertex \(k\) is an OTP shared partner of ordered pair \((i,j)\) iff \(i \to k \to j\). Also known as "transitive shared partner". - Incoming Two-path (`"ITP"`): vertex \(k\) is an ITP shared partner of ordered pair \((i,j)\) iff \(j \to k \to i\). Also known as "cyclical shared partner" - Reciprocated Two-path (`"RTP"`): vertex \(k\) is an RTP shared partner of ordered pair \((i,j)\) iff \(i \leftrightarrow k \leftrightarrow j\). - Outgoing Shared Partner (`"OSP"`): vertex \(k\) is an OSP shared partner of ordered pair \((i,j)\) iff \(i \to k, j \to k\). - Incoming Shared Partner (`"ISP"`): vertex \(k\) is an ISP shared partner of ordered pair \((i,j)\) iff \(k \to i, k \to j\). By default, outgoing two-paths (`"OTP"`) are calculated. Note that Robins et al. (2009) define closely related statistics to several of the above, using slightly different terminology.
[`ergmTerm`] for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "dse", "subsection")