This term adds one network statistic to the model for each element in `d` where the \(i\) th such statistic equals the number of edges in the network with exactly `d[i]` shared friends. For a directed network, multiple shared friend definitions are possible.
# binary: esf(d, type="OTP", L.base=NULL, in_order=FALSE)a vector of distinct integers
logical; if TRUE, compute the lagged version of the esf statistic based on the previous time point's network
A string indicating the type of shared partner or path to be considered for directed networks: `"OTP"` (default for directed), `"ITP"`, `"RTP"`, `"OSP"`, and `"ISP"`; has no effect for undirected. See the section below on Shared partner types for details.
specify the base of the triad, either by '+' and '-' or 1 and -1
While there is only one shared partner configuration in the undirected case, nine distinct configurations are possible for directed graphs, selected using the `type` argument. Currently, terms may be defined with respect to five of these configurations; they are defined here as follows (using terminology from Butts (2008) and the `relevent` package): - Outgoing Two-path (`"OTP"`): vertex \(k\) is an OTP shared partner of ordered pair \((i,j)\) iff \(i \to k \to j\). Also known as "transitive shared partner". - Incoming Two-path (`"ITP"`): vertex \(k\) is an ITP shared partner of ordered pair \((i,j)\) iff \(j \to k \to i\). Also known as "cyclical shared partner" - Reciprocated Two-path (`"RTP"`): vertex \(k\) is an RTP shared partner of ordered pair \((i,j)\) iff \(i \leftrightarrow k \leftrightarrow j\). - Outgoing Shared Partner (`"OSP"`): vertex \(k\) is an OSP shared partner of ordered pair \((i,j)\) iff \(i \to k, j \to k\). - Incoming Shared Partner (`"ISP"`): vertex \(k\) is an ISP shared partner of ordered pair \((i,j)\) iff \(k \to i, k \to j\). By default, outgoing two-paths (`"OTP"`) are calculated. Note that Robins et al. (2009) define closely related statistics to several of the above, using slightly different terminology.
[`ergmTerm`] for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "esf", "subsection")