Learn R Programming

ergm.sign (version 0.1.2)

fixL-ergmConstraint: Logical layer constraint

Description

This layer-aware constraint limits the sample space to those networks for which the specified logical layers are unchanged

Usage

# fixL(Ls)

Arguments

See Also

[`ergmConstraint`] for index of constraints and hints currently visible to the package.