This term adds a statistic equal to the geometrically weighted edgewise (not dyadwise) shared enemy distribution with decay parameter. For a directed network, multiple shared enemy definitions are possible.
# binary: gwese(decay, fixed=FALSE, cutoff=30, type="OTP", base=NULL, in_order=FALSE)nonnegative decay parameter for the shared enemy or selected directed analogue count; required if `fixed=TRUE` and ignored with a warning otherwise.
optional argument indicating whether the `decay` parameter is fixed at the given value, or is to be fit as a curved exponential-family model (see Hunter and Handcock, 2006). The default is `FALSE` , which means the scale parameter is not fixed and thus the model is a curved exponential family.
logical; if TRUE, compute the lagged version of the gwese statistic based on the previous time point's network
This optional argument sets the number of underlying ESE terms to use in computing the statistics when `fixed=FALSE`, in order to reduce the computational burden. Its default value can also be controlled by the `gw.cutoff` term option control parameter. (See `?control.ergm`.)
A string indicating the type of shared partner or path to be considered for directed networks: `"OTP"` (default for directed), `"ITP"`, `"RTP"`, `"OSP"`, and `"ISP"`; has no effect for undirected. See the section below on Shared partner types for details.
specify the base of the triad, either by '+' and '-' or 1 and -1
While there is only one shared partner configuration in the undirected case, nine distinct configurations are possible for directed graphs, selected using the `type` argument. Currently, terms may be defined with respect to five of these configurations; they are defined here as follows (using terminology from Butts (2008) and the `relevent` package): - Outgoing Two-path (`"OTP"`): vertex \(k\) is an OTP shared partner of ordered pair \((i,j)\) iff \(i \to k \to j\). Also known as "transitive shared partner". - Incoming Two-path (`"ITP"`): vertex \(k\) is an ITP shared partner of ordered pair \((i,j)\) iff \(j \to k \to i\). Also known as "cyclical shared partner" - Reciprocated Two-path (`"RTP"`): vertex \(k\) is an RTP shared partner of ordered pair \((i,j)\) iff \(i \leftrightarrow k \leftrightarrow j\). - Outgoing Shared Partner (`"OSP"`): vertex \(k\) is an OSP shared partner of ordered pair \((i,j)\) iff \(i \to k, j \to k\). - Incoming Shared Partner (`"ISP"`): vertex \(k\) is an ISP shared partner of ordered pair \((i,j)\) iff \(k \to i, k \to j\). By default, outgoing two-paths (`"OTP"`) are calculated. Note that Robins et al. (2009) define closely related statistics to several of the above, using slightly different terminology.
[`ergmTerm`] for index of model terms currently visible to the package.
ergm:::.formatTermKeywords("ergmTerm", "gwese", "subsection")