Learn R Programming

ergm.sign (version 0.1.2)

sponsor: Common Sponsor Data for Syrian Civil War Factions

Description

A data frame containing binary indicators for whether each faction in the Syrian civil war is sponsored by a common external actor.

Arguments

Format

A matrix with 68 rows and 68 columns.

References

fritz2023allergm.sign

Examples

Run this code
data(sponsor)

Run the code above in your browser using DataLab