Learn R Programming

ergm.sign (version 0.1.2)

tribes: Read Highland Tribes

Description

A static network of political alliances and enmities among the 16 Gahuku-Gama sub-tribes of Eastern Central Highlands of New Guinea, documented by read1954cultures;textualergm.sign.

Arguments

Format

An undirected static.sign object with no loops.

References

Taken from UCINET IV, which cites the following: hage1983structuralergm.sign, read1954culturesergm.sign

Examples

Run this code
# \donttest{
data(tribes)
# }

Run the code above in your browser using DataLab