Create a nodematch term where node attributes come from the previous network's node attribute `attr`. The previous network used is the one indexed by the current `GroupID` (equivalent to `lag=1` previously). This constructs a temporary node attribute `delnodecov_<attr>` on the current network (copied from the previous net) and calls `nodematch` on that attribute.
# binary: delnodematch(attr)character attribute name to copy from the previous network into the current.