powered by
This layer-aware constraint limits the sample space to those networks for which the specified logical layers are unchanged
# fixL(Ls)
[`ergmConstraint`] for index of constraints and hints currently visible to the package.