mple_sign: Fit an ERGM with MPLE using a logistic regression model
Description
Returns a fitted logistic regression model used to calculate the maximum
pseudolikelihood estimate (MPLE) of an exponential random graph model (ERGM).
Usage
mple_sign(
formula,
control = control.ergm(),
seed = NULL,
eval_lik = FALSE,
...
)
Value
An object of class ergm.
Arguments
- formula
An ERGM formula with the network on the left-hand side.
- control
A list of control parameters for ergmMPLE.
By default, the covariance method is set to "Godambe".
- seed
Optional integer to set the random seed for reproducibility when
simulating networks for Godambe covariance estimation.
- eval_lik
Logical indicating whether to evaluate the likelihood using path sampling.
- ...
Additional arguments passed to ergmMPLE.
Details
The MPLE is calculated by first computing matrices of positive and negative
change statistics. These are then used to estimate the MPLE via logistic
regression. Optionally, the covariance can be estimated using the Godambe
method.
Examples
Run this codedata(tribes)
mple_sign(tribes ~ Pos(~edges) + Neg(~edges))
Run the code above in your browser using DataLab