powered by
A data frame containing binary indicators for whether each faction in the Syrian civil war is sponsored by a common external actor.
A matrix with 68 rows and 68 columns.
fritz2023allergm.sign
data(sponsor)
Run the code above in your browser using DataLab